django-dynamic-choices
======================

.. image:: https://travis-ci.org/charettes/django-dynamic-choices.svg?branch=master
    :target: https://travis-ci.org/charettes/django-dynamic-choices
    :alt: Build Status

.. image:: https://coveralls.io/repos/charettes/django-dynamic-choices/badge.svg?branch=master
    :target: https://coveralls.io/r/charettes/django-dynamic-choices?branch=master
    :alt: Coverage Status

Django appilcation that provides fk and m2m dynamic choices and react to django.contrib.admin
edit/add view interaction to update those choices.

Installation
------------

.. code:: sh

    pip install django-dynamic-choices
